#
# spec file for package nomacs
#
# Copyright (c) 2025 mantarimay
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pver a869962f051504dd2c1dedeb3bc3d266c17070c1
Name:           nomacs
Version:        3.21.0
Release:        1.1
Summary:        Lightweight image viewer
License:        GPL-3.0-or-later
Group:          Productivity/Graphics/Viewers
URL:            https://nomacs.org/
Source0:        https://github.com/nomacs/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        https://github.com/v-tyrtov/nomacs-plugins/archive/%{pver}/nomacs-plugins-%{pver}.tar.gz 
BuildRequires:  cmake >= 2.8
BuildRequires:  fdupes
%if 0%{?suse_version} < 1600
BuildRequires:  clang
%else
BuildRequires:  gcc-c++ >= 8
%endif
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(OpenCV)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Core5Compat)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6LinguistTools)
BuildRequires:  cmake(Qt6PrintSupport)
BuildRequires:  cmake(Qt6Concurrent)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  pkgconfig(exiv2) >= 0.26
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(libraw) >= 0.17
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(zlib)
Requires:       kf6-kimageformats
Recommends:     %{name}-lang
Recommends:     %{name}-plugins

%description
nomacs is a free image viewer, which is small, fast and able to handle the
most common image formats. Additionally it is possible to synchronise
multiple viewers. A synchronisation of viewers running on the same
computer or via LAN is possible. It allows to compare images and spot the
differences (e.g. schemes of architects to show the progress).

%package plugins	
Summary:        Plugins for nomacs image viewer
Requires:       %{name} = %{version}

%description plugins	
Some usefull plugins for nomacs:
- Affine transformations
- RGB image from greyscales
- Fake miniature filter
- Page extractions
- Painting

%lang_package

%prep
%autosetup -p1
tar xf %{SOURCE1} --strip-components 1 -C ImageLounge/plugins/

%build
%if 0%{?suse_version} < 1600
export CC=/usr/bin/clang
export CXX=/usr/bin/clang++
%endif
pushd ImageLounge/
%cmake \
  -DCMAKE_BUILD_TYPE=Release                           \
  -DCMAKE_C_FLAGS='%{optflags} -fno-strict-aliasing'   \
  -DCMAKE_CXX_FLAGS='%{optflags} -fno-strict-aliasing' \
  -DQT_VERSION_MAJOR=6                                 \
  -DUSE_SYSTEM_QUAZIP=ON                               \
  -DCMAKE_SHARED_LINKER_FLAGS=""                       \
  -DENABLE_TRANSLATIONS=ON
%make_build
popd

%install
pushd ImageLounge/
%cmake_install
popd

rm %{buildroot}%{_libdir}/lib%{name}*.so
%suse_update_desktop_file org.%{name}.ImageLounge
%find_lang %{name} --with-qt
# find_lang doesn't escape paths, but language paths contain "Image Lounge" with space,
# we'll escape the paths manually
sed -i -E 's|(%{_datadir}.*)$|"\1"|' %{name}.lang
%fdupes %{buildroot}%{_datadir}/

# fix zero-length
rm %{buildroot}%{_datadir}/nomacs/Image\ Lounge/themes/System.css

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_libdir}/lib%{name}*.so.*
%{_datadir}/%{name}/
%exclude "%{_datadir}/nomacs/Image Lounge/translations/"
%{_datadir}/applications/org.%{name}.ImageLounge.desktop
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/hicolor/scalable/apps/org.%{name}.ImageLounge.svg
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/org.%{name}.ImageLounge.appdata.xml
%{_mandir}/man?/%{name}.?%{?ext_man}

%files plugins
%doc ImageLounge/plugins/README.md
%dir %{_libdir}/nomacs-plugins
%{_libdir}/nomacs-plugins/*.so.*
# should be in devel but unneeded to include in or make new the package
%exclude %{_libdir}/nomacs-plugins/*.so

%files lang -f %{name}.lang
%dir "%{_datadir}/nomacs/Image Lounge/translations/"

%changelog
* Mon Mar  3 2025 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 3.21.0
  * Refactored thumbnail and general image loader
  * Support for mirrored orientation
  * Light and Dark Themes
  * Various bug fixes, code clean-ups and minor refactoring
* Fri Aug 30 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 3.19.1
  * fix non-maximized window at startup on GNOME
  * Give default focus to central widget
  * Fix incorrect positioning when sorted by metadata
  * add logging for moveToTrash
  * save selection on directory change
  * Fix navigation loss after file deletion
* Tue Jul 16 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 3.19.0
  * Fix mouse wheel behavior with Alt modifier
  * Fix random comparison of images
  * Fix missing window icon when running under Wayland
  * Fix wrong coordinates in crop toolbar
  * Fix incorrect crop tooltip when rotating
  * fix broken zip thumbnails
  * Fix infinite loop when scanning subfolder
  * Fix segfaults or hangs when sorting
  * Fix segfault in history dock when last tab is closed
  * Fix status bar displaying wrong zoom
  * Fix segfault on thumbnailer
* Sat Jul  6 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Build leap with clang: gcc version doesn't support c++17
* Thu Apr 25 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Add kf6-kimageformats Requires: Enable QOI format support
* Sat Apr 13 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Ported to Qt6
- Remove unneeded BuildRequires:
  * pkgconfig(Qt5Concurrent)
  * pkgconfig(Qt5Network)
  * pkgconfig(Qt5PrintSupport)
  * pkgconfig(Qt5Svg)
  * pkgconfig(Qt5Widgets)
  * quazip-qt5-devel
  * lcov
  * libqt5-linguist-devel
  * opencv-qt5-devel
- Add ported Qt6 BuildRequires:
  * hicolor-icon-theme
  * cmake(OpenCV)
  * cmake(Qt6Core)
  * cmake(Qt6Core5Compat)
  * cmake(Qt6Network)
  * cmake(Qt6LinguistTools)
  * cmake(Qt6PrintSupport)
  * cmake(Qt6Concurrent)
  * cmake(Qt6Svg)
- Change source plugin to git v-tyrtov for support Qt6 build
* Thu Mar 14 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 3.17.2295
  * Option to close nomacs with middle mouse button if enabled in
    settings
  * QOI (Quite OK Image Format) support (needs kimageformats 5.110)
  * Possibility to build nomacs with Exiv2 0.28.0
  * Remove implicit auto-save.
  * Revert crop functionality.
  * extends the new crop tool
  * fixes crash when anti-aliasing is enabled
  * improves translations
- Remove unneeded patch:
  * quazip1_cmake_remove_after_new_version.diff
  * nomacs-fix-exiv2-0.28.patch
- Add source and subpackage nomacs-plugins
* Wed Aug  2 2023 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Add nomacs-fix-exiv2-0.28.patch to fix libexiv2 build errors
* Thu Oct 29 2020 Petr Vanek <petr@yarpen.cz>
- QuaZip1 migration
  * patch quazip1_cmake_remove_after_new_version.diff also
    sent to the upstream
* Fri Aug  7 2020 Namor Barcode <z1trus@gmx.com> - 3.16.224
- Update to version 3.16.224
  * avif support
  * cr3, pcx support added
  * default system theme added
  * edit: adds blur
  * translations updated
  * plugins: adds composite image plugin
  * bug fixes
* Mon Mar 16 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 3.14:
  * Add HEIF/HEIC support.
  * Add metadata filtering.
  * Reduce start-up time.
  * Bug fixes.
- Remove nomacs-3.12-fix-DkImageStorage.patch,
  Fix-build-with-GCC9.patch: fixed upstream.
* Sun Feb 23 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Add nomacs-3.12-fix-DkImageStorage.patch: Fix DkImageStorage
  (commits e4d0c079, 7779c75b).
- Drop openSUSE Leap 42.x support.
* Mon Sep  2 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add Fix-build-with-GCC9.patch.
* Fri Jan 25 2019 pavlk@pavlk.cz
- Update to version 3.12:
  * New icon theme,
  * An improved dark theme
  * Speed-ups
  * Recent files panel renewed
  * New icon theme
  * Improved drag&drop of thumbnail preview (copy/move/link)
  * Editable zoom levels
  * Fill transparent background with a color added
  * LAN client removed
  * Batch: original filename is added to the metadata
  * Frameless: multi-screen setup improved
  * SVG: resulting image size can be adjusted when converting
  * RLE compressed TGA support
  * Bug fixes
- Remove nomacs-use-quazip-qt5.patch.
* Thu Jul 12 2018 sor.alexei@meowr.ru
- Update to version 3.10.2:
  * Fix disabling update interactions.
  * Add config.ini that can be used for multi-user systems.
  * Restore mng and jp2 support.
* Wed Jul 11 2018 sor.alexei@meowr.ru
- Update to version 3.10.1 (changes since 3.8.1):
  * Improve anti-aliasing.
  * Improve printing.
  * Print multiple pages from thumbnail preview.
  * Support animated WebP.
  * Support JPG compressed TIFFs.
  * Add batch cropping.
  * Update the PSD library.
  * Add Qt style/ plugins.
  * Add padding to HUD labels (e.g. zoom).
  * Add new translations: Bosnian, Croation, Serbian.
- Remove nomacs-3.8.1-fix-qt-5.11.patch.
* Tue Jun 12 2018 sor.alexei@meowr.ru
- Add nomacs-3.8.1-fix-qt-5.11.patch: Fix Qt 5.11+ compatibility.
* Mon Apr 16 2018 sor.alexei@meowr.ru
- Update to version 3.8.1:
  * Update lipqpsd.
  * Add themes.
  * Add a basic dark theme.
- Use the %%license tag for licences.
* Tue Feb 20 2018 aloisio@gmx.com
- Added nomacs-use-quazip-qt5.patch to link against quazip-qt5
* Sun Nov 26 2017 sor.alexei@meowr.ru
- Build with the Release build type (gh#opencv/opencv#10105).
- Re-enable locales.
* Fri Nov 10 2017 sor.alexei@meowr.ru
- Update to version 3.8.0:
  * Full PhaseOne Support (Monochrome).
  * Optimise RAW loader (less RAM & speed-up).
  * Improve RAW loading (reduce pink pixels).
  * Fix Drag & Drop.
  * Fix batch resize.
  * Fix GPS link.
  * Fix the translation downloader.
- Remove nomacs-remove-datetime.patch.
* Tue Mar 28 2017 sor.alexei@meowr.ru
- Update to version 3.6.1 (changes since 3.4):
  * Introduce image adjustments.
  * Add Exposure.
  * Batch:
    + Improve profiles
    + Add image adjustments.
    + Add settings for batch plugins
  * Extended tab functions.
  * Settings Editor
  * Icons for high DPI displays.
  * Fix a crash on exit.
  * Move bug reporting to GitHub.
- Add nomacs-remove-datetime.patch: Remove __DATE__ and __TIME__.
* Sat Jul 23 2016 sor.alexei@meowr.ru
- Update to version 3.4:
  * Rework Batch UI.
  * Add Batch Profiles.
  * Cropping to metadata.
  * Improve RGB to Gray.
  * Fix crash on delete.
  * Fix slow thumbnail rendering.
  * Improve start-up time.
  * Fix RAW/PSD orientation.
- Remove nomacs-3.2.0-gcc6.patch: fixed upstream.
- Remove /usr/lib(|64)/libnomacs*.so files: for development, yet
  no development seem possible for nomacs now.
- Add ldconfig to post(|un).
* Fri Jun 17 2016 sor.alexei@meowr.ru
- Add nomacs-3.2.0-gcc6.patch from
  https://github.com/nomacs/nomacs/issues/62: fix GCC6 errors
  (boo#985374).
* Wed May  4 2016 sor.alexei@meowr.ru
- Update to version 3.2.0:
  * Redesign plugin framework.
  * New preferences.
  * Add Undo & History dock.
  * Improve statusbar (e.g. zoom level).
  * All Icons are SVG (UHD monitors).
  * Add compression to Batch.
  * Extend image transitions (swipe).
- Remove nomacs-3.0.0-opencv-detection.patch: fixed upstream.
* Fri Mar  4 2016 sor.alexei@meowr.ru
- Add nomacs-3.0.0-opencv-detection.patch to fix detection of
  OpenCV 3.x and later.
* Thu Dec 17 2015 sor.alexei@meowr.ru
- Update to 3.0.0:
  * Add plugins support.
  * Full SVG support.
  * Add Quick Launch.
  * Add Tiny Planet option.
  * Improve batch processing.
  * Add command line arguments.
  * Improve zoom control.
  * Add Bulgarian and Ukrainian translations.
- Remove nomacs-qt5-build-fix.patch.
* Thu Aug 20 2015 sor.alexei@meowr.ru
- Update to 2.4.6:
  * Directory ScrollBar added again (and updated).
  * Fix various crashes (metadata saving/displaying).
  * Fix sorting.
  * Fix some minor bugs.
- Rebase nomacs-qt5-build-fix.patch.
* Fri Apr 17 2015 sor.alexei@meowr.ru
- Update to 2.4.4:
  * Improved batch processing (add images from multiple directories).
  * New Metadata HUD panel (choose entries dynamically).
  * Default strings are now translated.
  * File sorting is (hopefully) fixed.
  * Gamma correction for rescaling is now 16 bit (smooth gradients).
  * Zoom to Fit added (replaces ‘Reset Zoom’).
  * Saving of multiple tabs.
  * UTF-8 encoding for image notes.
  * General stability improvements.
- Rebase nomacs-qt5-build-fix.patch.
* Mon Mar  2 2015 sor.alexei@meowr.ru
- Update to 2.4.2:
  * Image Manipulations are fixed now (black images on e.g. gamma).
  * Resize with gamma correction (black images if gamma was
    checked).
  * Crash fix (if reload occurred after an image resize).
  * Fix Batch Processing.
  * Fix GIF movie toolbar.
  * Update translations.
- Add nomacs-qt5-build-fix.patch.
* Thu Feb 26 2015 sor.alexei@meowr.ru
- Update to 2.4.0:
  * Batch processing (you can try it by clicking
    Tools > Batch Processing).
  * Image tabs (open multiple images within different tabs).
  * Thumbnail preview improved (copy/paste delete/rename is now
    supported).
  * Zoom panel improved (you can now chose a specific zoom level).
  * Olympus RAW added.
  * Convert to grayscale added.
  * Faster directory loading (especially if you have many images
    in a directory).
  * Gesture improvements.
  * Saving of images from archives (e.g. zip, docx) is now supported.
  * File sorting improved.
  * Stability improvements.
- Remove nomacs-strcmp-fix.patch and nomacs-qt5-build-fix.patch.
* Wed Nov 12 2014 sor.alexei@meowr.ru
- Update to 2.2.0:
  * Bugfixes and new features
    (see http://nomacs.org/redmine for details).
- Compile against Qt5 instead of Qt4.
- Rebase nomacs-strcmp-fix.patch.
- Add nomacs-qt5-build-fix.patch.
* Sun Aug  3 2014 sor.alexei@meowr.ru
- Update to 2.0.2.
* Thu Apr 17 2014 sor.alexei@meowr.ru
- Update to 1.6.4.
- Embrace openSUSE packaging policy.
* Sun Feb 24 2013 ti.eugene@gmail.com
- Update to 1.0.
* Thu May 24 2012 petr@scribus.info
- Update to 0.3.2.
* Sat Mar  3 2012 petr@scribus.info
- Update to 0.3.0.
* Mon Dec  5 2011 petr@scribus.info
- Initial package.
